==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../../../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Повністю розряджено</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Розрядження</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Повністю заряджено</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Заряджання</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Літій-іон</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Літій-полімер</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Літій фосфат заліза</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Свинцево кислотний</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Нікель кадмій</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Нікель металогідрат</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Персональний цифровий асистент батареї</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Батарея безперебійного живлення</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Основна батарея</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Батарея мишки</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Батарея клавіатури</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Батарея клавіатури і мишки</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Батарея камери</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Батарея телефону</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Батарея монітору</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Невідома батарея</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../../../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
    <message>
        <location filename="../../../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Інформація про батарею</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Менеджер живлення</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Температура:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Повний профіль заряду:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Повний заряд:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Заряд зараз:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Частота заряду:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Технологія:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Напруга:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Виробник:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../../../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Немає батареї!</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQT не в змозі знайти дані про жодну з батарей - спостереження вимкнене</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Низький заряд!</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="125"/>
        <source>Suspending in %1 seconds</source>
        <translation>Призупинення через %1 секунд</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %1 seconds</source>
        <translation>Сплячка через %1 секунд</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %1 seconds</source>
        <translation>Виключення через %1 секунд</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="50"/>
        <source>LXQt Idleness watcher failed to start</source>
        <translation>Вартовий незавантаженості LXQT не запустився</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="73"/>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation>D-Bus інтерфейс для org.freedesktop.ScreenSaver вже зареєстровано </translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="107"/>
        <source>The X11 Screensaver extension is not usable</source>
        <translation>Розширення зберігача екрану X11 не працює</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="114"/>
        <source>Configure...</source>
        <translation>Налаштування...</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="179"/>
        <source>ERROR: Screen unlocked</source>
        <translation>ПОМИЛКА: Екран відімкнено</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="181"/>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation>Замикаюча програма &quot;%1&quot; завершилася з кодом помилки %2 </translation>
    </message>
    <message>
        <location filename="../../../idlenesswatcher.cpp" line="183"/>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation>Замикаюча програма &quot;%1&quot; вилетіла в трубу з кодом помилки %2</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../../../powermanagementd.cpp" line="107"/>
        <source>Power Management</source>
        <translation>Керування живленням</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="108"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Ви запустили менеджер живлення LXQT вперше.
Його можна сконфігурувати, використовуючи налаштування... </translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="109"/>
        <source>Configure...</source>
        <translation>Налаштування...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="61"/>
        <location filename="../../../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Виключити значок</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Менеджер живлення LXQt&lt;/b&gt;&lt;br/&gt;  - Менеджер живлення для середовища стільниці LXQt&lt;/p&gt;&lt;p&gt;  Автори:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - та інші з проектів Razor і LXQt&lt;/p&gt;&lt;p&gt;  Всі права застережено &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>Інформація про менеджер живлення LXQT</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Іконкe системного лотка менеджера живлення LXQT можна включити в програмі &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; </translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Налаштувати зараз</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../../../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Повністю розряджено</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Розрядження</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Повністю заряджено</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Заряджання</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Літій-іон</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Літій-полімер</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Літій фосфат заліза</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Свинцево кислотний</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Нікель кадмій</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Нікель металогідрат</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Персональний цифровий асистент батареї</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Батарея безперебійного живлення</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Основна батарея</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Батарея мишки</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Батарея клавіатури</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Батарея клавіатури і мишки</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Батарея камери</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Батарея телефону</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Батарея монітору</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Невідома батарея</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../../../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
    <message>
        <location filename="../../../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Інформація про батарею</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Менеджер живлення</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Температура:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Стан:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Повний профіль заряду:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Повний заряд:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Заряд зараз:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Частота заряду:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Технологія:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Напруга:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Виробник:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../../../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Немає батареї!</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQT не в змозі знайти дані про жодну з батарей - спостереження вимкнене</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Низький заряд!</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="125"/>
        <source>Suspending in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Suspending in %1 seconds</source>
        <translation type="vanished">Призупинення через %1 секунд</translation>
    </message>
    <message>
        <source>Hibernating in %1 seconds</source>
        <translation type="vanished">Сплячка через %1 секунд</translation>
    </message>
    <message>
        <source>Shutting down in %1 seconds</source>
        <translation type="vanished">Виключення через %1 секунд</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <source>LXQt Idleness watcher failed to start</source>
        <translation type="vanished">Вартовий незавантаженості LXQT не запустився</translation>
    </message>
    <message>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation type="vanished">D-Bus інтерфейс для org.freedesktop.ScreenSaver вже зареєстровано </translation>
    </message>
    <message>
        <source>The X11 Screensaver extension is not usable</source>
        <translation type="vanished">Розширення зберігача екрану X11 не працює</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="vanished">Налаштування...</translation>
    </message>
    <message>
        <source>ERROR: Screen unlocked</source>
        <translation type="vanished">ПОМИЛКА: Екран відімкнено</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation type="vanished">Замикаюча програма &quot;%1&quot; завершилася з кодом помилки %2 </translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation type="vanished">Замикаюча програма &quot;%1&quot; вилетіла в трубу з кодом помилки %2</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../../../powermanagementd.cpp" line="110"/>
        <source>Power Management</source>
        <translation>Керування живленням</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="111"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Ви запустили менеджер живлення LXQT вперше.
Його можна сконфігурувати, використовуючи налаштування... </translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="112"/>
        <source>Configure...</source>
        <translation>Налаштування...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="61"/>
        <location filename="../../../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Виключити значок</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Менеджер живлення LXQt&lt;/b&gt;&lt;br/&gt;  - Менеджер живлення для середовища стільниці LXQt&lt;/p&gt;&lt;p&gt;  Автори:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - та інші з проектів Razor і LXQt&lt;/p&gt;&lt;p&gt;  Всі права застережено &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>Інформація про менеджер живлення LXQT</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Іконкe системного лотка менеджера живлення LXQT можна включити в програмі &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; </translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Налаштувати зараз</translation>
    </message>
</context>
</TS>
